/*=================================================================
 * Modele DoubleWeibull en C et double precision
 * Pour la
 * Simulation de strategie optimale, version C
 * Voir BaranyiRoberts pour les E/S
 * COMPILATION sous matlab par: 
 * mex  /home/abouvier/MONFILTREX/v2013-1.0/SRC/SIMULATION_STRATEGIE/C/CDoubleWeibull.c

 *============================================================*/
#include <math.h>
#include "mex.h"
double pow( double base, double exponent );
double log10( double arg );

  /* ============================================================== */      

void  CDoubleWeibullDP(double *param, double * temps, 
        double *valmin, double *valmax, double *rep,
        int ntemps, int N, int Ncur)
{

double alpha=(double) param[Ncur];
double p=(double) param[N+Ncur];
double delta1= (double) param[2*N+Ncur];
double delta2= (double) param[3*N+Ncur];
double log10N0= (double) param[4*N+Ncur];

 
 int i, ind, u;
 double aux1, aux2, aux3, aux4, ti;

 for ( i=0; i< ntemps; i++) {
   ti=temps[i];
   aux1 = -  pow((ti/delta1), p) + alpha;
   aux2 = -  pow((ti/delta2), p);
   aux3 = pow(10.0, aux1);
   aux4= pow(10.0, aux2);

   ind=N*i+Ncur;
   rep[ind]= log10N0 - log10(1+ pow(10, alpha)) + log10(aux3+aux4);

 /* Ramener dans les bornes les réponses invalides */
   /*ATT: ce qu'on a calculé, c'est log10(Nt) */
   /*  Nt doit etre >0 => log10(Nt) >1 */

    if (rep[ind] < (*valmin)) {
      rep[ind]=(double)(*valmin);
    }
    if (rep[ind] > (*valmax)) {
      rep[ind]=(double)(*valmax);
    }
     
 } /* fin i */


}
/* ============================================================== */
void CDoubleWeibull(double *param,  double *temps, 
 double *valmin, double *valmax,
  double *rep,int ntemps,
  int N)
{

    /* boucle sur l'appel à DoubleWeibullDP */
    int u;
    for (u=0; u<N; u++) {
        CDoubleWeibullDP( param,  temps,valmin, valmax,  rep, ntemps, N, u);
    }

}

/* ================================================== */
/* The gateway function:
INPUT
nlhs: le nombre de sorties (la fonction a pls sorties quand
 l'utilisateur affecte une structure à pls composants
 à son appel a CDoubleWeibull)
plhs: les sorties
nrhs: le nombre d'arguments d'entrée
prhs: les arguments d'entrée
 */
void mexFunction( int nlhs, mxArray *plhs[],
                  int nrhs, const mxArray *prhs[] )
{
  double *rep, *param, *temps, *valmin, *valmax;
  int N, ntemps;

  

/* The first input argument param is Nxnf */
  N = (int) mxGetM(prhs[0]);
 
   
/* create a pointer to the  input   */
param = mxGetPr(prhs[0]);

/* Second input argument: times is 1 x ntemps */
ntemps = (int) mxGetN(prhs[1]);

temps=mxGetPr(prhs[1]);

/* Third input argument:valmin */
    valmin=(double *)mxGetPr(prhs[2]);
/* Fourth input argument:valmax */
    valmax=(double *)mxGetPr(prhs[3]);

/* 5th input argument: result matrix */
    rep = (double *)mxGetPr(prhs[4]);

/* create the output matrix 
 plhs[0] = mxCreateDoubleMatrix((mwSize)N,(mwSize)ntemps,mxREAL);
rep = mxGetPr(plhs[0]);
*/

/* call the computational routine */
 CDoubleWeibull( param,  temps, valmin, valmax, rep,(int)ntemps, (int)N);

} 
